# Static Materials with intricate shapes
This module contains a (currently rather small) collection of objects with a shape that is more intricate than a basic cuboid.

::: fdtdx.objects.static_material.Cylinder
An object with the shape of a cylinder.
